@@ -13,18 +13,19 @@
 # ----------------------------------------------------------------------
 
 package Text::BibTeX;
+use Text::BibTeX::Name;
+use Text::BibTeX::NameFormat;
 
 use 5.008001;                          # needed for Text::BibTeX::Entry
 
 use strict;
-#use UNIVERSAL qw(isa can);              # for 'check_class' subroutine
 use Carp;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
 require Exporter;
 require DynaLoader;
 
-our $VERSION='0.73';
+our $VERSION='0.75';
 
 @ISA = qw(Exporter DynaLoader);
 %EXPORT_TAGS = (nodetypes => [qw(BTAST_STRING BTAST_MACRO BTAST_NUMBER)],
@@ -45,9 +46,52 @@ our $VERSION='0.73';
               @{$EXPORT_TAGS{'nodetypes'}},
               @{$EXPORT_TAGS{'nameparts'}},
               @{$EXPORT_TAGS{'joinmethods'}},
-              'check_class', 'display_list');
+              'check_class', 'display_list' );
 @EXPORT = @{$EXPORT_TAGS{'metatypes'}};
 
+use Encode 'encode', 'decode';
+use Unicode::Normalize;
+
+sub _process_result {
+  no strict 'refs';
+  my ( $self, $result, $encoding, $norm ) = @_;
+
+  $norm ||= "NFC"; # best to force it here.
+  my $normsub = \&{"$norm"}; # symbolic ref
+    if ( $encoding eq "utf-8" ) {
+        if ( utf8::is_utf8($result) ) {
+            return $normsub->($result);
+        }
+        else {
+            return $normsub->( decode( $encoding, $result ) );
+        }
+    }
+    else { return $result; }
+
+}
+
+sub _process_argument {
+    my ( $self, $value, $encoding ) = @_;
+
+     if ( $encoding eq "utf-8" && utf8::is_utf8($value)) {
+         return encode( $encoding, $value );
+     }
+     else {
+        return $value;
+    }
+}
+
+sub split_list {
+    my ( $field, $delim, $filename, $line, $desc, $opts ) = @_;
+    $opts                  ||= {};
+    $opts->{binmode}       ||= 'bytes';
+    $opts->{normalization} ||= 'NFC';
+    return
+        map { Text::BibTeX->_process_result( $_, $opts->{binmode}, $opts->{normalization} ) }
+        Text::BibTeX::isplit_list( $field, $delim, $filename, $line, $desc );
+
+}
+
 =head1 NAME
 
 Text::BibTeX - interface to read and parse BibTeX files
@@ -572,7 +616,7 @@ of it as appropriate.  They're just mentioned here for completeness.
 
 =over 4
 
-=item split_list (STRING, DELIM [, FILENAME [, LINE [, DESCRIPTION]]])
+=item split_list (STRING, DELIM [, FILENAME [, LINE [, DESCRIPTION [, OPTS]]]])
 
 Splits a string on a fixed delimiter according to the BibTeX rules for
 splitting up lists of names.  With BibTeX, the delimiter is hard-coded
@@ -581,7 +625,23 @@ STRING are considered delimiters if they are at brace-depth zero,
 surrounded by whitespace, and not at the beginning or end of STRING; the
 comparison is case-insensitive.  See L<bt_split_names> for full details
 of how splitting is done (it's I<not> the same as Perl's C<split>
-function).
+function). OPTS is a hash ref of the same binmode and normalization
+arguments as with, e.g. Text::BibTeX::File->open(). split_list calls isplit_list()
+internally but handles UTF-8 conversion and normalization, if requested.
+
+Returns the list of strings resulting from splitting STRING on DELIM.
+
+=item isplit_list (STRING, DELIM [, FILENAME [, LINE [, DESCRIPTION]]])
+
+Splits a string on a fixed delimiter according to the BibTeX rules for
+splitting up lists of names.  With BibTeX, the delimiter is hard-coded
+as C<"and">; here, you can supply any string.  Instances of DELIM in
+STRING are considered delimiters if they are at brace-depth zero,
+surrounded by whitespace, and not at the beginning or end of STRING; the
+comparison is case-insensitive.  See L<bt_split_names> for full details
+of how splitting is done (it's I<not> the same as Perl's C<split>
+function). This function returns bytes. Use Text::BibTeX::split_list to specify
+the same binmode and normalization arguments as with, e.g. Text::BibTeX::File->open()
 
 Returns the list of strings resulting from splitting STRING on DELIM.
 
