@@ -23,7 +23,7 @@ use vars qw'$VERSION';
 use Carp;
 use Text::BibTeX qw(:metatypes :nodetypes);
 
-$VERSION = 0.73;
+$VERSION = 0.75;
 
 =head1 NAME
 
@@ -31,7 +31,7 @@ Text::BibTeX::Entry - read and parse BibTeX files
 
 =head1 SYNOPSIS
 
-   use Text::BibTeX;            # do not use Text::BibTeX::Entry alone!
+   use Text::BibTeX::Entry;
 
    # ...assuming that $bibfile and $newbib are both objects of class
    # Text::BibTeX::File, opened for reading and writing (respectively):
@@ -271,6 +271,8 @@ sub read
    my $fn = $source->{'filename'};
    my $fh = $source->{'handle'};
    $self->{'file'} = $source;        # store File object for later use
+   $self->{binmode} = $source->{binmode};
+   $self->{normalization} = $source->{normalization};
    return $self->parse ($fn, $fh, $preserve);
 }
 
@@ -392,27 +394,39 @@ context.)
 
 =item fieldlist ()
 
-Returns the list of fields in the entry.  In a scalar context, returns a
-reference to the object's own list of fields.  That way, you can change or
-reorder the field list with minimal interference from the class.  I'm not
-entirely sure if this is a good idea, so don't rely on it existing in the
-future; feel free to play around with it and let me know if you get bitten
-in dangerous ways or find this enormously useful.
+Returns the list of fields in the entry.  
+
+B<WARNING> In scalar context, it no longer returns a
+reference to the object's own list of fields.
 
 =cut
 
 sub parse_ok   { shift->{'status'}; }
 
-sub metatype   { shift->{'metatype'}; }
+sub metatype   {
+    my $self = shift;
+    Text::BibTeX->_process_result( $self->{'metatype'}, $self->{binmode}, $self->{normalization} );
+}
 
-sub type       { shift->{'type'}; }
+sub type {
+    my $self = shift;
+    Text::BibTeX->_process_result( $self->{'type'}, $self->{binmode}, $self->{normalization} );
+}
 
-sub key        { shift->{'key'}; }
+sub key        { 
+  my $self = shift;
+  exists $self->{key}
+    ? Text::BibTeX->_process_result($self->{key}, $self->{binmode}, $self->{normalization})
+    : undef;
+}
 
 sub num_fields { scalar @{shift->{'fields'}}; }
 
-sub fieldlist  { wantarray ? @{shift->{'fields'}} : shift->{'fields'}; }
-
+sub fieldlist  { 
+  my $self = shift;
+  return map { Text::BibTeX->_process_result($_, $self->{binmode}, $self->{normalization})} @{$self->{'fields'}};
+}
+  
 =item exists (FIELD)
 
 Returns true if a field named FIELD is present in the entry, false
@@ -484,17 +498,24 @@ sub exists
 {
    my ($self, $field) = @_;
 
-   exists $self->{'values'}{$field};
+   exists $self->{values}{Text::BibTeX->_process_argument($field, $self->{binmode}, $self->{normalization})};
 }
 
 sub get
 {
    my ($self, @fields) = @_;
 
-   @{$self->{'values'}}{@fields};
+   my @x = @{$self->{'values'}}{map {Text::BibTeX->_process_argument($_, $self->{binmode}, $self->{normalization})} @fields};
+
+   @x = map {defined($_) ? Text::BibTeX->_process_result($_, $self->{binmode}, $self->{normalization}): undef} @x;
+
+   return (@x > 1) ? @x : $x[0];
 }
 
-sub value { shift->{'value'} }
+sub value { 
+  my $self = shift;
+  Text::BibTeX->_process_result($self->{value}, $self->{binmode}, $self->{normalization});
+}
 
 
 =head2 Author name methods
@@ -590,17 +611,19 @@ sub split
 {
    my ($self, $field, $delim, $desc) = @_;
 
-   return unless $self->exists ($field);
+   return unless $self->exists($field);
    $delim ||= 'and';
    $desc ||= 'name';
 
-   my $filename = ($self->{'file'} && $self->{'file'}{'filename'});
-   my $line = $self->{'lines'}{$field};
-
 #   local $^W = 0                        # suppress spurious warning from 
 #      unless defined $filename;         # undefined $filename
-   Text::BibTeX::split_list ($self->{'values'}{$field}, $delim,
-                             $filename, $line, $desc);
+   Text::BibTeX::split_list($self->{values}{$field},
+                            $delim,
+                            ($self->{file} && $self->{file}{filename}),
+                            $self->{lines}{$field},
+                            $desc,
+                            {binmode       => $self->{binmode},
+                             normalization => $self->{normalization}});
 }
 
 sub names
@@ -618,7 +641,8 @@ sub names
 #      unless defined $filename;         # undefined $filename
    for $i (0 .. $#names)
    {
-      $names[$i] = Text::BibTeX::Name->new($names[$i], $filename, $line, $i);
+      $names[$i] = Text::BibTeX::Name->new(
+        {binmode => $self->{binmode}, normalization => $self->{normalization}},$names[$i], $filename, $line, $i);
    }
    @names;
 }
@@ -696,7 +720,7 @@ sub set_key
 {
    my ($self, $key) = @_;
 
-   $self->{'key'} = $key;
+   $self->{'key'} = Text::BibTeX->_process_argument($key, $self->{binmode}, $self->{normalization});
 }
 
 sub set
@@ -708,7 +732,7 @@ sub set
 
    while (@_)
    {
-      ($field,$value) = (shift,shift);
+      ($field,$value) = (shift,Text::BibTeX->_process_argument(shift, $self->{binmode}, $self->{normalization}));
       push (@{$self->{'fields'}}, $field)
          unless exists $self->{'values'}{$field};
       $self->{'values'}{$field} = $value;
@@ -870,7 +894,8 @@ sub print_s
 
    # Tack on the last line, and we're done!
    $output .= "}\n\n";
-   $output;
+   
+   Text::BibTeX->_process_result($output, $self->{binmode}, $self->{normalization});
 }
 
 =back
