@@ -22,7 +22,7 @@ use Carp;
 use IO::File;
 
 use vars qw'$VERSION';
-$VERSION = 0.74;
+$VERSION = 0.75;
 
 =head1 NAME
 
@@ -30,12 +30,12 @@ Text::BibTeX::File - interface to whole BibTeX files
 
 =head1 SYNOPSIS
 
-   use Text::BibTeX;     # this loads Text::BibTeX::File
+   use Text::BibTeX::File;
 
-   $bib = new Text::BibTeX::File "foo.bib" or die "foo.bib: $!\n";
+   $bib = Text::BibTeX::File->new("foo.bib") or die "foo.bib: $!\n";
    # or:
-   $bib = new Text::BibTeX::File;
-   $bib->open ("foo.bib") || die "foo.bib: $!\n";
+   $bib =  Text::BibTeX::File->new;
+   $bib->open("foo.bib", {binmode => 'utf-8', normalization => 'NFC'}) || die "foo.bib: $!\n";
 
    $bib->set_structure ($structure_name,
                         $option1 => $value1, ...);
@@ -61,19 +61,46 @@ These concepts are fully documented in L<Text::BibTeX::Structure>.
 
 =over 4
 
-=item new ([FILENAME [,MODE [,PERMS]]]) 
+=item new ([FILENAME], [OPTS]) 
 
-Creates a new C<Text::BibTeX::File> object.  If FILENAME is supplied,
-passes it to the C<open> method (along with MODE and PERMS if they
-are supplied).  If the C<open> fails, C<new> fails and returns false; if
-the C<open> succeeds (or if FILENAME isn't supplied), C<new> returns the
-new object reference.
+Creates a new C<Text::BibTeX::File> object.  If FILENAME is supplied, passes
+it to the C<open> method (along with OPTS).  If the C<open> fails, C<new>
+fails and returns false; if the C<open> succeeds (or if FILENAME isn't
+supplied), C<new> returns the new object reference.
 
-=item open (FILENAME [,MODE [,PERMS]])
+=item open (FILENAME [OPTS])
 
-Opens the file specified by FILENAME, possibly using MODE and PERMS.
-See L<IO::File> for full semantics; this C<open> is just a front end for
-C<IO::File::open>.
+Opens the file specified by FILENAME. OPTS is an hashref that can have
+the following values:
+
+=over 4
+
+=item MODE
+
+mode as specified by L<IO::File>
+
+=item PERMS
+
+permissions as specified by L<IO::File>. Can only be used in conjunction
+with C<MODE>
+
+=item BINMODE
+
+by default, Text::BibTeX uses bytes directly. Thus, you need to encode
+strings accordingly with the encoding of the files you are reading. You can
+also select UTF-8. In this case, Text::BibTeX will return UTF-8 strings in
+NFC mode. Note that at the moment files with BOM are not supported.
+
+Valid values are 'raw/bytes' or 'utf-8'.
+
+=item NORMALIZATION
+
+by default, Text::BibTeX outputs UTF-8 in NFC form. You can change this by passing
+the name of a different form.
+
+Valid values are those forms supported by the Unicode::Normalize module ('NFD', 'NFDK' etc.)
+
+=back 
 
 =item close ()
 
@@ -95,19 +122,40 @@ sub new
 
    $class = ref ($class) || $class;
    my $self = bless {}, $class;
-   ($self->open (@_) || return undef) if @_; # filename [, mode [, perms]]
+   ($self->open (@_) || return undef) if @_; 
    $self;
 }
 
-sub open
-{
-   my $self = shift;
+sub open {
+    my ($self) = shift;
+    $self->{filename} = shift;
 
-   $self->{filename} = $_[0];
-   $self->{handle} = new IO::File;
-   $self->{handle}->open (@_);          # filename, maybe mode, maybe perms
+    $self->{binmode} = 'bytes';
+    $self->{normalization} = 'NFC';
+    my @args = ( $self->{filename} );
+
+    if ( ref $_[0] eq "HASH" ) {
+        my $opts = {};
+        $opts = shift;
+        $opts->{ lc $_ } = $opts->{$_} for ( keys %$opts );
+        $self->{binmode} = 'utf-8'
+            if exists $opts->{binmode} && $opts->{binmode} =~ /utf-?8/i;
+        $self->{normalization} = $opts->{normalization} if exists $opts->{normalization};
+
+        if ( exists $opts->{MODE} ) {
+            push @args, $opts->{MODE};
+            push @args, $opts->{PERMS} if exists $opts->{PERMS};
+        }
+    }
+    else {
+        push @args, @_;
+    }
+
+    $self->{handle} = IO::File->new;
+    $self->{handle}->open(@args);    # filename, maybe mode, maybe perms
 }
 
+
 sub close
 {
    my $self = shift;
@@ -155,7 +203,7 @@ sub set_structure
    croak "Text::BibTeX::File::set_structure: options list must have even " .
          "number of elements"
       unless @options % 2 == 0;
-   $self->{structure} = new Text::BibTeX::Structure ($structure, @options);
+   $self->{structure} = Text::BibTeX::Structure->new($structure, @options);
 }
 
 sub structure { shift->{structure} }
