@@ -23,7 +23,7 @@ require 5.004;
 use strict;
 use Carp;
 use vars qw'$VERSION';
-$VERSION = 0.73;
+$VERSION = 0.75;
 
 =head1 NAME
 
@@ -31,6 +31,8 @@ Text::BibTeX::NameFormat - format BibTeX-style author names
 
 =head1 SYNOPSIS
 
+   use Text::BibTeX::NameFormat;
+
    $format = Text::BibTeX::NameFormat->($parts, $abbrev_first);
 
    $format->set_text ($part,
@@ -39,6 +41,7 @@ Text::BibTeX::NameFormat - format BibTeX-style author names
 
    $format->set_options ($part, $abbrev, $join_tokens, $join_part
 
+   ## Uses the encoding/binmode and normalization form stored in $name
    $formatted_name = $format->apply ($name);
 
 =head1 DESCRIPTION
@@ -118,7 +121,7 @@ sub new
    my ($class, $parts, $abbrev_first) = @_;
 
    $parts ||= "fvlj";
-   $abbrev_first //= 0;
+   $abbrev_first = defined($abbrev_first)? $abbrev_first : 0;
 
    die unless $parts =~ /[fvlj]{1,4}/;
 
@@ -242,7 +245,12 @@ sub apply
       croak "invalid Name object: no C structure";
    my $format_struct = $self->{'_cstruct'} ||
       croak "invalid NameFormat object: no C structure";
-   format_name ($name_struct, $format_struct);
+ 
+   my $ans = format_name ($name_struct, $format_struct);
+
+   $ans = Text::BibTeX->_process_result($ans, $name->{binmode}, $name->{normalization});
+   
+   return $ans;
 }
 
 =back
